# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['starknet_devnet', 'starknet_devnet.blueprints']

package_data = \
{'': ['*'],
 'starknet_devnet': ['accounts_artifacts/OpenZeppelin/0.1.0/Account.cairo/*']}

install_requires = \
['Flask[async]>=2.0.3,<2.1.0',
 'Werkzeug>=2.0.3,<2.1.0',
 'cairo-lang==0.8.1',
 'dill>=0.3.4,<0.4.0',
 'flask-cors>=3.0.10,<3.1.0',
 'meinheld>=1.0.2,<1.1.0']

entry_points = \
{'console_scripts': ['starknet-devnet = starknet_devnet.server:main']}

setup_kwargs = {
    'name': 'starknet-devnet',
    'version': '0.1.22',
    'description': 'A local testnet for Starknet',
    'long_description': '## Introduction\n\nA Flask wrapper of Starknet state. Similar in purpose to Ganache.\n\nAims to mimic Starknet\'s Alpha testnet, but with simplified functionality.\n\n## Contents\n\n- [Install](#install)\n- [Disclaimer](#disclaimer)\n- [Run](#run)\n- [Interaction](#interaction)\n- [Dumping and Loading](#dumping)\n- [Hardhat Integration](#hardhat-integration)\n- [L1-L2 Postman Communication](#postman-integration)\n- [Block Explorer](#block-explorer)\n- [Lite Mode](#lite-mode)\n- [Restart](#restart)\n- [Contract debugging](#contract-debugging)\n- [Development](#development)\n\n## Install\n\n```text\npip install starknet-devnet\n```\n\n### Requirements\n\nWorks with Python versions >=3.7.2 and <=3.9.10.\n\nOn Ubuntu/Debian, first run:\n\n```text\nsudo apt install -y libgmp3-dev\n```\n\nOn Mac, you can use `brew`:\n\n```text\nbrew install gmp\n```\n\n## Disclaimer\n\n- Devnet should not be used as a replacement for Alpha testnet. After testing on Devnet, be sure to test on testnet (alpha-goerli)!\n- Specifying a block by its hash/number is not supported. All interaction is done with the latest block.\n- Read more in [interaction](#interaction).\n\n## Run\n\nInstalling the package adds the `starknet-devnet` command.\n\n```text\nusage: starknet-devnet [-h] [-v] [--host HOST] [--port PORT]\n\nRun a local instance of Starknet Devnet\n\noptional arguments:\n  -h, --help            show this help message and exit\n  -v, --version         Print the version\n  --host HOST           Specify the address to listen at; defaults to localhost (use the address the program outputs on start)\n  --port PORT, -p PORT  Specify the port to listen at; defaults to 5000\n  --load-path LOAD_PATH\n                        Specify the path from which the state is loaded on\n                        startup\n  --dump-path DUMP_PATH\n                        Specify the path to dump to\n  --dump-on DUMP_ON     Specify when to dump; can dump on: exit, transaction\n```\n\n### Run with Docker\n\nDevnet is available as a Docker container ([shardlabs/starknet-devnet](https://hub.docker.com/repository/docker/shardlabs/starknet-devnet)):\n\n```text\ndocker pull shardlabs/starknet-devnet\n```\n\nThe server inside the container listens to the port 5000, which you need to publish to a desired `<PORT>` on your host machine:\n\n```text\ndocker run -p [HOST:]<PORT>:5000 shardlabs/starknet-devnet\n```\n\nE.g. if you want to use your host machine\'s `127.0.0.1:5000`, you need to run:\n\n```text\ndocker run -p 127.0.0.1:5000:5000 shardlabs/starknet-devnet\n```\n\nYou may ignore any address-related output logged on container startup (e.g. `Running on all addresses` or `Running on http://172.17.0.2:5000`). What you will use is what you specified with the `-p` argument.\n\nIf you don\'t specify the `HOST` part, the server will indeed be available on all of your host machine\'s addresses (localhost, local network IP, etc.), which may present a security issue if you don\'t want anyone from the local network to access your Devnet instance.\n\n## Interaction\n\n- Interact with Devnet as you would with the official Starknet [Alpha testnet](https://www.cairo-lang.org/docs/hello_starknet/amm.html?highlight=alpha#interaction-examples).\n- The exact underlying API is not exposed for the same reason Alpha testnet does not expose it.\n- To use Devnet with Starknet CLI, provide Devnet\'s URL to the `--gateway_url` and `--feeder_gateway_url` options of Starknet CLI commands.\n- The following Starknet CLI commands are supported:\n  - `call`\n  - `deploy`\n  - `estimate_fee`\n  - `get_block`\n  - `get_code`\n  - `get_full_contract`\n  - `get_state_update`\n  - `get_storage_at`\n  - `get_transaction`\n  - `get_transaction_receipt`\n  - `get_transaction_trace`\n  - `invoke` (currently will fail for max_fee > 0)\n  - `tx_status`\n- The following Starknet CLI commands are **not** supported:\n  - `get_contract_addresses`\n\n## Hardhat integration\n\n- If you\'re using [the Hardhat plugin](https://github.com/Shard-Labs/starknet-hardhat-plugin), see [here](https://github.com/Shard-Labs/starknet-hardhat-plugin#testing-network) on how to edit its config file to integrate Devnet.\n\n## Postman integration\n\nPostman is a Starknet utility that allows testing L1 <> L2 interactions. To utilize this, you can use [`starknet-hardhat-plugin`](https://github.com/Shard-Labs/starknet-hardhat-plugin), as witnessed in [this example](https://github.com/Shard-Labs/starknet-hardhat-example/blob/master/test/postman.test.ts). Or you can directly interact with the two Postman-specific endpoints:\n\n- Load a `StarknetMockMessaging` contract. The `address` parameter is optional; if provided, the `StarknetMockMessaging` contract will be fetched from that address, otherwise a new one will be deployed:\n\n  - `POST /postman/load_l1_messaging_contract`\n  - body: `{ "networkUrl": "http://localhost:5005", "address": "0x83D76591560d9CD02CE16c060c92118d19F996b3" }`\n  - `networkUrl` - the URL of the L1 network you\'ve run locally or that already exists; possibilities include, and are not limited to:\n    - [Goerli testnet](https://goerli.net/)\n    - [Ganache node](https://www.npmjs.com/package/ganache)\n    - [Hardhat node](https://hardhat.org/hardhat-network/#running-stand-alone-in-order-to-support-wallets-and-other-software).\n\n- Flush. This will go through the new enqueued messages sent from L1 and send them to L2. This has to be done manually for L1 -> L2, but for L2 -> L1, it is done automatically:\n  - `POST /postman/flush`\n  - body: None\n\nThis method of L1 <> L2 communication testing differs from Starknet Alpha networks. Taking the [L1L2Example.sol](https://www.cairo-lang.org/docs/_static/L1L2Example.sol) contract in the [starknet documentation](https://www.cairo-lang.org/docs/hello_starknet/l1l2.html):\n\n```\nconstructor(IStarknetCore starknetCore_) public {\n        starknetCore = starknetCore_;\n}\n```\n\nThe constructor takes an `IStarknetCore` contract as argument, however for Devnet L1 <> L2 communication testing, this will have to be replaced with the [MockStarknetMessaging.sol](https://github.com/starkware-libs/cairo-lang/blob/master/src/starkware/starknet/testing/MockStarknetMessaging.sol) contract:\n\n```\nconstructor(MockStarknetMessaging mockStarknetMessaging_) public {\n    starknetCore = mockStarknetMessaging_;\n}\n```\n\n## Dumping\n\nTo preserve your Devnet instance for future use, there are several options:\n\n- Dumping on exit (handles Ctrl+C, i.e. SIGINT, doesn\'t handle SIGKILL):\n\n```\nstarknet-devnet --dump-on exit --dump-path <PATH>\n```\n\n- Dumping after each transaction (done in background, doesn\'t block):\n\n```\nstarknet-devnet --dump-on transaction --dump-path <PATH>\n```\n\n- Dumping on request (replace `<HOST>`, `<PORT>` and `<PATH>` with your own):\n\n```\ncurl -X POST http://<HOST>:<PORT>/dump -d \'{ "path": <PATH> }\' -H "Content-Type: application/json"\n```\n\n### Loading\n\nTo load a preserved Devnet instance, run:\n\n```\nstarknet-devnet --load-path <PATH>\n```\n\n### Enabling dumping and loading with Docker\n\nTo enable dumping and loading if running Devnet in a Docker container, you must bind the container path with the path on your host machine.\n\nThis example:\n\n- Relies on [Docker bind mount](https://docs.docker.com/storage/bind-mounts/); try [Docker volume](https://docs.docker.com/storage/volumes/) instead.\n- Assumes that `/actual/dumpdir` exists. If unsure, use absolute paths.\n- Assumes you are listening on `127.0.0.1:5000`.\n\nIf there is `dump.pkl` inside `/actual/dumpdir`, you can load it with:\n\n```\ndocker run \\\n  -p 127.0.0.1:5000:5000 \\\n  --mount type=bind,source=/actual/dumpdir,target=/dumpdir \\\n  shardlabs/starknet-devnet \\\n  --load-path /dumpdir/dump.pkl\n```\n\nTo dump to `/actual/dumpdir/dump.pkl` on Devnet shutdown, run:\n\n```\ndocker run \\\n  -p 127.0.0.1:5000:5000 \\\n  --mount type=bind,source=/actual/dumpdir,target=/dumpdir \\\n  shardlabs/starknet-devnet \\\n  --dump-on exit --dump-path /dumpdir/dump.pkl\n```\n\n## Block explorer\n\nA local block explorer (Voyager), as noted [here](https://voyager.online/local-version/), apparently cannot be set up to work with Devnet. Read more in [this issue](https://github.com/Shard-Labs/starknet-devnet/issues/60).\n\n## Lite mode\n\nTo improve Devnet performance, consider passing these CLI flags on Devnet startup:\n\n- `--lite-mode` enables all of the optimizations described below (same as using all of the following flags);\n- `--lite-mode-deploy-hash` disables the calculation of the transaction hash for deploy transactions. It will instead be a simple sequence of numbers;\n- `--lite-mode-block-hash` disables the calculation of the block hash. It will instead be a simple sequence of numbers;\n\n## Restart\n\nDevnet can be restarted by making a `POST /restart` request. All of the deployed contracts, blocks and storage updates will be restarted to the empty state.\n\n## Contract debugging\n\nIf your contract is using `print` in cairo hints (it was compiled with the `--disable-hint-validation` flag), Devnet will output those lines together with its regular server output. To filter out just your debugging print lines, redirect stderr to /dev/null when starting Devnet:\n\n```\nstarknet-devnet 2> /dev/null\n```\n\nTo enable printing with a dockerized version of Devnet set `PYTHONUNBUFFERED=1`:\n\n```\ndocker run -p 127.0.0.1:5000:5000 -e PYTHONUNBUFFERED=1 shardlabs/starknet-devnet\n```\n\n## Development\n\nIf you\'re a developer willing to contribute, be sure to have installed [Poetry](https://pypi.org/project/poetry/) and all the dependency packages.\n\n```text\npip install poetry\npoetry install\n```\n\n### Development - Run\n\n```text\npoetry run starknet-devnet\n```\n\n### Development - Test\n\nWhen running tests locally, do it from the project root:\n\n```text\npoetry run pytest test/\n```\n\nor for a single file\n\n```text\npoetry run pytest test/<TEST_FILE>\n```\n\n### Development - Build\n\nYou don\'t need to build anything to be able to run locally, but if you need the `*.whl` or `*.tar.gz` artifacts, run\n\n```text\npoetry build\n```\n',
    'author': 'FabijanC',
    'author_email': 'fabijan.corak@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Shard-Labs/starknet-devnet',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7.2,<4.0.0',
}


setup(**setup_kwargs)
